@@ -1,4 +1,3 @@
-/* $Id$ */
 /*
  *  Copyright (c) 2008 Stephan Arts <stephan@xfce.org>
  *                     Jannis Pohlmann <jannis@xfce.org>
@@ -13,9 +12,9 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Library General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  You should have received a copy of the GNU General Public License along
+ *  with this program; if not, write to the Free Software Foundation, Inc.,
+ *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -50,6 +49,7 @@ static GOptionEntry entries[] =
 
 /* global xfconf channel */
 static XfconfChannel *accessibility_channel = NULL;
+static XfconfChannel *session_channel = NULL;
 
 
 
@@ -63,11 +63,48 @@ accessibility_settings_sensitivity (GtkToggleButton *button,
 
 
 
+static void
+accessibility_settings_at (GtkToggleButton *button,
+                           GtkBuilder      *builder)
+{
+  AtkObject  *atkobj;
+  GObject    *info_logout;
+  GObject    *no_atspi;
+  gchar     **atspi;
+
+  info_logout = gtk_builder_get_object (builder, "info-logout");
+  no_atspi = gtk_builder_get_object (builder, "info-no-at");
+
+  gtk_widget_hide (GTK_WIDGET (info_logout));
+  gtk_widget_hide (GTK_WIDGET (no_atspi));
+
+  if (gtk_toggle_button_get_active (button))
+    {
+      atspi = xfce_resource_match (XFCE_RESOURCE_CONFIG, "autostart/at-spi-*.desktop", TRUE);
+      atkobj = gtk_widget_get_accessible (GTK_WIDGET (button));
+
+      if (atspi == NULL || g_strv_length (atspi) == 0)
+        gtk_widget_show (GTK_WIDGET (no_atspi));
+      else if (!GTK_IS_ACCESSIBLE (atkobj))
+        gtk_widget_show (GTK_WIDGET (info_logout));
+
+      g_strfreev (atspi);
+    }
+}
+
+
+
 static void
 accessibility_settings_dialog_configure_widgets (GtkBuilder *builder)
 {
     GObject *box, *object;
 
+    /* assistive technologies */
+    object = gtk_builder_get_object (builder, "start-at");
+    xfconf_g_property_bind (session_channel, "/general/StartAssistiveTechnologies", G_TYPE_BOOLEAN, object, "active");
+    g_signal_connect (object, "toggled", G_CALLBACK (accessibility_settings_at), builder);
+    accessibility_settings_at (GTK_TOGGLE_BUTTON (object), builder);
+
     /* Sticky keys */
     object = gtk_builder_get_object (builder, "sticky-keys-enabled");
     box = gtk_builder_get_object (builder, "sticky-keys-box");
@@ -122,6 +159,19 @@ accessibility_settings_dialog_configure_widgets (GtkBuilder *builder)
 
 
 
+static void
+accessibility_settings_dialog_response (GtkWidget *dialog,
+                                        gint       response_id)
+{
+    if (response_id == GTK_RESPONSE_HELP)
+        xfce_dialog_show_help_with_version (GTK_WINDOW (dialog), "xfce4-settings", "accessibility",
+                                            NULL, XFCE4_SETTINGS_VERSION_SHORT);
+    else
+        gtk_main_quit ();
+}
+
+
+
 gint
 main (gint argc, gchar **argv)
 {
@@ -176,8 +226,9 @@ main (gint argc, gchar **argv)
         return EXIT_FAILURE;
     }
 
-    /* open the channel */
+    /* open the channels */
     accessibility_channel = xfconf_channel_new ("accessibility");
+    session_channel = xfconf_channel_new ("xfce4-session");
 
     /* hook to make sure the libxfce4ui library is linked */
     if (xfce_titled_dialog_get_type () == 0)
@@ -196,15 +247,14 @@ main (gint argc, gchar **argv)
             /* Get the dialog widget */
             dialog = gtk_builder_get_object (builder, "dialog");
 
-            gtk_widget_show (GTK_WIDGET (dialog));
-            g_signal_connect (dialog, "response", G_CALLBACK (gtk_main_quit), NULL);
+            g_signal_connect (dialog, "response",
+                G_CALLBACK (accessibility_settings_dialog_response), NULL);
+            gtk_window_present (GTK_WINDOW (dialog));
 
             /* To prevent the settings dialog to be saved in the session */
             gdk_set_sm_client_id ("FAKE ID");
 
             gtk_main ();
-
-            gtk_widget_destroy (GTK_WIDGET (dialog));
         }
         else
         {
@@ -237,8 +287,9 @@ main (gint argc, gchar **argv)
     /* Release Builder */
     g_object_unref (G_OBJECT (builder));
 
-    /* release the channel */
+    /* release the channels */
     g_object_unref (G_OBJECT (accessibility_channel));
+    g_object_unref (G_OBJECT (session_channel));
 
     /* shutdown xfconf */
     xfconf_shutdown();
