@@ -189,7 +189,10 @@ send_selection_notify (GsdClipboardManager *manager,
                     (XEvent *)&notify);
         XSync (manager->priv->display, False);
 
-        gdk_error_trap_pop ();
+        if (gdk_error_trap_pop () != 0)
+        {
+                g_critical ("Failed to notify clipboard selection");
+        }
 }
 
 static void
@@ -216,7 +219,10 @@ finish_selection_request (GsdClipboardManager *manager,
                     False, NoEventMask, (XEvent *) &notify);
         XSync (manager->priv->display, False);
 
-        gdk_error_trap_pop ();
+        if (gdk_error_trap_pop () != 0)
+        {
+                g_critical ("Failed to send selection request");
+        }
 }
 
 static int
@@ -406,6 +412,7 @@ send_incrementally (GsdClipboardManager *manager,
         IncrConversion *rdata;
         gulong          length;
         gulong          items;
+        gulong          bytes;
         guchar         *data;
 
         list = g_slist_find_custom (manager->priv->conversions, xev,
@@ -422,7 +429,9 @@ send_incrementally (GsdClipboardManager *manager,
 
         rdata->offset += length;
 
-        items = length / clipboard_bytes_per_item (rdata->data->format);
+        bytes = clipboard_bytes_per_item (rdata->data->format);
+        items = bytes == 0 ? 0 : length / bytes;
+
         XChangeProperty (manager->priv->display, rdata->requestor,
                          rdata->property, rdata->data->type,
                          rdata->data->format, PropModeAppend,
@@ -533,6 +542,7 @@ convert_clipboard_target (IncrConversion      *rdata,
         gint               n_targets;
         GSList            *list;
         gulong             items;
+        gulong             bytes;
         XWindowAttributes  atts;
 
         if (rdata->target == XA_TARGETS) {
@@ -571,7 +581,8 @@ convert_clipboard_target (IncrConversion      *rdata,
                 }
 
                 rdata->data = target_data_ref (tdata);
-                items = tdata->length / clipboard_bytes_per_item (tdata->format);
+                bytes = clipboard_bytes_per_item (tdata->format);
+                items = bytes == 0 ? 0 : tdata->length / bytes;
                 if (tdata->length <= SELECTION_MAX_SIZE)
                         XChangeProperty (manager->priv->display, rdata->requestor,
                                          rdata->property,
@@ -594,7 +605,10 @@ convert_clipboard_target (IncrConversion      *rdata,
 
                         XSync (manager->priv->display, False);
 
-                        gdk_error_trap_pop ();
+                        if (gdk_error_trap_pop () != 0)
+                        {
+                                g_critical ("Failed to transfer clipboard contents");
+                        }
                 }
         }
 }
